==> flutterskel-0.0.10.tar.gz: lib/provider/ProviderBuilder.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/configuration/Configuration.dart' as arch;
import 'package:flutterskel/resources/colors/ColorResources.dart';
import 'package:flutterskel/resources/dimensions/DimensionResources.dart';
import 'package:flutterskel/resources/fonts/FontResources.dart';
import 'package:flutterskel/resources/strings/StringResources.dart' as arch;
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart' as arch;
import 'package:flutterskel/routing/page/PageRouter.dart' as arch;
import 'package:flutterskel/routing/url/UrlRouter.dart' as arch;
import 'package:flutterskel/userinformation/UserInformationRepository.dart' as arch;
import 'package:provider/provider.dart';

abstract class ProviderBuilder<
                  // Data
                  DataSource,
                  // Routing
                  UrlRouter extends arch.UrlRouter,
                  PageRouter extends arch.PageRouter,
                  // Configuration
                  Configuration extends arch.Configuration,
                  // User Information
                  UserInformationRepository extends arch.UserInformationRepository,
                  // Theme Related: Repository -> Theme -> Fonts -> Dimensions/Colors
                  Colors extends ColorResources,
                  Dimensions extends DimensionResources,
                  Fonts extends FontResources,
                  ThemeRepository extends arch.ThemeRepository,

                  // Strings
                  Strings extends arch.StringResources,
                  // Images & Icons
                  Images,
                  Icons> {

  // DataSource
  DataSource _dataSource;
  DataSource buildDataSource();
  DataSource _getDataSource() {
    if(_dataSource == null) {
      _dataSource = buildDataSource();
    }
    return _dataSource;
  }

  // Page Router
  PageRouter _pageRouter;
  PageRouter buildPageRouter();
  PageRouter _getPageRouter() {
    if(_pageRouter == null) {
      _pageRouter = buildPageRouter();
    }
    return _pageRouter;
  }

  // Url Router
  UrlRouter _urlRouter;
  UrlRouter buildUrlRouter();
  UrlRouter _getUrlRouter() {
    if(_urlRouter == null) {
      _urlRouter = buildUrlRouter();
    }
    return _urlRouter;
  }

  // Configuration
  Configuration _configuration;
  Configuration buildConfiguration();
  Configuration _getConfiguration() {
    if(_configuration == null) {
      _configuration = buildConfiguration();
    }
    return _configuration;
  }

  // Images
  Images _images;
  Images buildImages();
  Images _getImages() {
    if(_images == null) {
      _images = buildImages();
    }
    return _images;
  }

  // Strings
  StringsRepository _stringsRepository;
  Strings buildStringsResources();
  StringsRepository _getStringsRepository() {
    if(_stringsRepository == null) {
      _stringsRepository = StringsRepository<Strings>(
        strings: buildStringsResources()
      );
    }
    return _stringsRepository;
  }

  // User Information
  UserInformationRepository _userInformationRepository;
  UserInformationRepository buildUserInformationRepository();
  UserInformationRepository _getUserInformationRepository() {
    if(_userInformationRepository == null) {
      _userInformationRepository = buildUserInformationRepository();
    }
    return _userInformationRepository;
  }

  // Colors
  Colors _colors;
  Colors buildColors();
  Colors getColors() {
    if(_colors == null) {
      _colors = buildColors();
    }
    return _colors;
  }

  // Dimensions
  Dimensions _dimensions;
  Dimensions buildDimensions();
  Dimensions getDimensions() {
    if(_dimensions == null) {
      _dimensions = buildDimensions();
    }
    return _dimensions;
  }

  // Fonts
  Fonts _fonts;
  Fonts buildFonts();
  Fonts getFonts() {
    if(_fonts == null) {
      _fonts = buildFonts();
    }
    return _fonts;
  }

  // Icons
  Icons _icons;
  Icons buildIcons();
  Icons _getIcons() {
    if(_icons == null) {
      _icons = buildIcons();
    }
    return _icons;
  }

  // Theme
  ThemeRepository _themeRepository;
  ThemeRepository buildThemeRepository();
  ThemeRepository _getThemeRepository() {
    if(_themeRepository == null) {
      _themeRepository = buildThemeRepository();
    }
    return _themeRepository;
  }


  List<SingleChildCloneableWidget> get providers => [
    // DataSource
    Provider<DataSource>.value(value: _getDataSource()),
    Provider<UrlRouter>.value(value: _getUrlRouter()),
    Provider<PageRouter>.value(value: _getPageRouter()),
    Provider<Images>.value(value: _getImages()),
    Provider<Icons>.value(value: _getIcons()),

    // Change Notifiers
    ChangeNotifierProvider<Configuration>.value(value: _getConfiguration()),
    ChangeNotifierProvider<UserInformationRepository>.value(value: _getUserInformationRepository()),
    ChangeNotifierProvider<StringsRepository>.value(value: _getStringsRepository()),
    ChangeNotifierProvider<ThemeRepository>.value(value: _getThemeRepository())
  ];

  MultiProvider build({@required Widget child}) {
    return MultiProvider(
      providers: providers,
      child: child,
    );
  }
}

==> flutterskel-0.0.11.tar.gz: lib/provider/ProviderBuilder.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/configuration/Configuration.dart' as arch;
import 'package:flutterskel/resources/colors/ColorResources.dart';
import 'package:flutterskel/resources/dimensions/DimensionResources.dart';
import 'package:flutterskel/resources/fonts/FontResources.dart';
import 'package:flutterskel/resources/strings/StringResources.dart' as arch;
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart' as arch;
import 'package:flutterskel/routing/page/PageRouter.dart' as arch;
import 'package:flutterskel/routing/url/UrlRouter.dart' as arch;
import 'package:flutterskel/userinformation/UserInformationRepository.dart' as arch;
import 'package:provider/provider.dart';

abstract class ProviderBuilder<
                  // Data
                  DataSource,
                  // Routing
                  UrlRouter extends arch.UrlRouter,
                  PageRouter extends arch.PageRouter,
                  // Configuration
                  Configuration extends arch.Configuration,
                  // User Information
                  UserInformationRepository extends arch.UserInformationRepository,
                  // Theme Related: Repository -> Theme -> Fonts -> Dimensions/Colors
                  Colors extends ColorResources,
                  Dimensions extends DimensionResources,
                  Fonts extends FontResources,
                  ThemeRepository extends arch.ThemeRepository,

                  // Strings
                  Strings extends arch.StringResources,
                  // Images & Icons
                  Images,
                  Icons> {

  // DataSource
  DataSource _dataSource;
  DataSource buildDataSource();
  DataSource getDataSource() {
    if(_dataSource == null) {
      _dataSource = buildDataSource();
    }
    return _dataSource;
  }

  // Page Router
  PageRouter _pageRouter;
  PageRouter buildPageRouter();
  PageRouter getPageRouter() {
    if(_pageRouter == null) {
      _pageRouter = buildPageRouter();
    }
    return _pageRouter;
  }

  // Url Router
  UrlRouter _urlRouter;
  UrlRouter buildUrlRouter();
  UrlRouter getUrlRouter() {
    if(_urlRouter == null) {
      _urlRouter = buildUrlRouter();
    }
    return _urlRouter;
  }

  // Configuration
  Configuration _configuration;
  Configuration buildConfiguration();
  Configuration getConfiguration() {
    if(_configuration == null) {
      _configuration = buildConfiguration();
    }
    return _configuration;
  }

  // Images
  Images _images;
  Images buildImages();
  Images getImages() {
    if(_images == null) {
      _images = buildImages();
    }
    return _images;
  }

  // Strings
  StringsRepository _stringsRepository;
  Strings buildStringsResources();
  StringsRepository _getStringsRepository() {
    if(_stringsRepository == null) {
      _stringsRepository = StringsRepository<Strings>(
        strings: buildStringsResources()
      );
    }
    return _stringsRepository;
  }

  // User Information
  UserInformationRepository _userInformationRepository;
  UserInformationRepository buildUserInformationRepository();
  UserInformationRepository getUserInformationRepository() {
    if(_userInformationRepository == null) {
      _userInformationRepository = buildUserInformationRepository();
    }
    return _userInformationRepository;
  }

  // Colors
  Colors _colors;
  Colors buildColors();
  Colors getColors() {
    if(_colors == null) {
      _colors = buildColors();
    }
    return _colors;
  }

  // Dimensions
  Dimensions _dimensions;
  Dimensions buildDimensions();
  Dimensions getDimensions() {
    if(_dimensions == null) {
      _dimensions = buildDimensions();
    }
    return _dimensions;
  }

  // Fonts
  Fonts _fonts;
  Fonts buildFonts();
  Fonts getFonts() {
    if(_fonts == null) {
      _fonts = buildFonts();
    }
    return _fonts;
  }

  // Icons
  Icons _icons;
  Icons buildIcons();
  Icons _getIcons() {
    if(_icons == null) {
      _icons = buildIcons();
    }
    return _icons;
  }

  // Theme
  ThemeRepository _themeRepository;
  ThemeRepository buildThemeRepository();
  ThemeRepository _getThemeRepository() {
    if(_themeRepository == null) {
      _themeRepository = buildThemeRepository();
    }
    return _themeRepository;
  }


  List<SingleChildCloneableWidget> get providers => [
    // DataSource
    Provider<DataSource>.value(value: _getDataSource()),
    Provider<UrlRouter>.value(value: _getUrlRouter()),
    Provider<PageRouter>.value(value: _getPageRouter()),
    Provider<Images>.value(value: _getImages()),
    Provider<Icons>.value(value: _getIcons()),

    // Change Notifiers
    ChangeNotifierProvider<Configuration>.value(value: _getConfiguration()),
    ChangeNotifierProvider<UserInformationRepository>.value(value: _getUserInformationRepository()),
    ChangeNotifierProvider<StringsRepository>.value(value: _getStringsRepository()),
    ChangeNotifierProvider<ThemeRepository>.value(value: _getThemeRepository())
  ];

  MultiProvider build({@required Widget child}) {
    return MultiProvider(
      providers: providers,
      child: child,
    );
  }
}
